Section

Struct Section 

pub struct Section {
    menu: MenuInstanceId,
    range: Range<usize>,
}
A handle to a contiguous range of slots added to a MenuBuilder.

Sections contain the id of the Menu they were made for and can only be created by a builder. Two Sections cannot cover the same range for the same Menu.

Fields

menu: MenuInstanceIdrange: Range<usize>

Implementations

Source

impl Section

pub(crate) fn new(menu: MenuInstanceId, range: impl Into<Range<usize>>) -> Self

pub const fn start(self) -> usize

The start of the section.

pub const fn end(self) -> usize

The end of the section.

pub const fn len(self) -> usize

The length of the section.

pub const fn is_empty(self) -> bool

Whether the section is empty (start == end).

pub const fn contains(self, slot_index: usize) -> bool

Whether the section contains an index.

pub const fn range(self) -> Range<usize>

A copy of the internal range.