pub struct Section {
menu: MenuInstanceId,
range: Range<usize>,
}Expand description
A handle to a contiguous range of slots added to a MenuBuilder.
Sections contain the id of the Menu they were made for and can only be
created by a builder. Two Sections cannot cover the same range for the same
Menu.
Fields
range: Range<usize>Implementations